==> tuia-advert-center-api-1.7.7-sources.jar: cn/com/duiba/tuia/core/api/dto/CreateNewMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto;


import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author zhangmeng
 * @time 2018.09.02
 * @function 修改默认素材，创建新素材，传递参数
 */
public class CreateNewMaterialDto implements Serializable {


    private static final long serialVersionUID = 5681015657921214156L;
    private Long advertId;

    private String bannerPng;

    private String buttonText;

    private String couponName;

    private String description;

    private String couponRemark;

    private String promoteURL;

    private String thumbnailPng;

    public CreateNewMaterialDto() {
    }

    public String getCouponRemark() {
        return couponRemark;
    }

    public void setCouponRemark(String couponRemark) {
        this.couponRemark = couponRemark;
    }

    public String getPromoteURL() {
        return promoteURL;
    }

    public void setPromoteURL(String promoteURL) {
        this.promoteURL = promoteURL;
    }

    public String getThumbnailPng() {
        return thumbnailPng;
    }

    public void setThumbnailPng(String thumbnailPng) {
        this.thumbnailPng = thumbnailPng;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getBannerPng() {
        return bannerPng;
    }

    public void setBannerPng(String bannerPng) {
        this.bannerPng = bannerPng;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> tuia-advert-center-api-2.4.70-sources.jar: cn/com/duiba/tuia/core/api/dto/CreateNewMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto;


import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author zhangmeng
 * @time 2018.09.02
 * @function 修改默认素材，创建新素材，传递参数
 */
public class CreateNewMaterialDto implements Serializable {


    private static final long serialVersionUID = 5681015657921214156L;
    private Long advertId;

    private String bannerPng;

    private String buttonText;

    private String couponName;

    private String description;

    private String couponRemark;

    private String promoteURL;

    private String thumbnailPng;

    private Long photoId;

    public CreateNewMaterialDto() {
        //do nothing
    }

    public String getCouponRemark() {
        return couponRemark;
    }

    public void setCouponRemark(String couponRemark) {
        this.couponRemark = couponRemark;
    }

    public String getPromoteURL() {
        return promoteURL;
    }

    public void setPromoteURL(String promoteURL) {
        this.promoteURL = promoteURL;
    }

    public String getThumbnailPng() {
        return thumbnailPng;
    }

    public void setThumbnailPng(String thumbnailPng) {
        this.thumbnailPng = thumbnailPng;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getBannerPng() {
        return bannerPng;
    }

    public void setBannerPng(String bannerPng) {
        this.bannerPng = bannerPng;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getCouponName() {
        return couponName;
    }

    public void setCouponName(String couponName) {
        this.couponName = couponName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getPhotoId() {
        return photoId;
    }

    public void setPhotoId(Long photoId) {
        this.photoId = photoId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
